@@ -833,7 +833,16 @@ cohens_f_squared <- function(model,
     )
 
   ## TODO: add back `effects = "fixed"` once the deprecation warning in parameters is removed
-  attr(out, "anova_type") <- tryCatch(attr(parameters::model_parameters(model, verbose = FALSE, es_type = NULL), "anova_type"),
+  attr(out, "anova_type") <- tryCatch(
+    attr(
+      parameters::model_parameters(
+        model,
+        verbose = FALSE,
+        es_type = NULL,
+        include_intercept = include_intercept
+      ),
+      "anova_type"
+    ),
     error = function(...) 1
   )
   attr(out, "approximate") <- TRUE
@@ -847,6 +856,7 @@ cohens_f_squared <- function(model,
                           generalized = FALSE,
                           ci = 0.95, alternative = "greater",
                           verbose = TRUE,
+                          include_intercept = FALSE,
                           ...) {
   # if (!inherits(model, c("Gam", "anova"))) {
   #   # Pass to ANOVA table method
@@ -865,13 +875,21 @@ cohens_f_squared <- function(model,
   # TODO this should be in .anova_es.anvoa
   # TODO the aoc method should convert to an anova table, then pass to anova
   ## TODO: add back `effects = "fixed"` once the deprecation warning in parameters is removed
-  params <- parameters::model_parameters(model, verbose = verbose, es_type = NULL)
+  params <- parameters::model_parameters(
+    model,
+    verbose = verbose,
+    es_type = NULL,
+    include_intercept = include_intercept
+  )
   out <- .es_aov_simple(as.data.frame(params),
     type = type,
     partial = partial, generalized = generalized,
-    ci = ci, alternative = alternative, verbose = verbose, ...
+    ci = ci, alternative = alternative, verbose = verbose,
+    include_intercept = include_intercept, ...
   )
-  if (is.null(attr(out, "anova_type"))) attr(out, "anova_type") <- attr(params, "anova_type")
+  if (is.null(attr(out, "anova_type"))) {
+    attr(out, "anova_type") <- attr(params, "anova_type")
+  }
   out
 }
 
@@ -892,7 +910,12 @@ cohens_f_squared <- function(model,
                               include_intercept = FALSE,
                               ...) {
   ## TODO: add back `effects = "fixed"` once the deprecation warning in parameters is removed
-  params <- parameters::model_parameters(model, verbose = verbose, es_type = NULL)
+  params <- parameters::model_parameters(
+    model,
+    verbose = verbose,
+    es_type = NULL,
+    include_intercept = include_intercept
+  )
   anova_type <- attr(params, "anova_type")
   params <- as.data.frame(params)
 
